#
# spec file for package kargo-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name kargo

Name:           kargo-cli
Version:        1.2.2
Release:        1.1
Summary:        CLI for the Kubernetes Application lifecycle orchestration
License:        Apache-2.0
URL:            https://github.com/akuity/kargo
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.23
BuildRequires:  zsh

%description
Kargo is a next-generation continuous delivery and application lifecycle
orchestration platform for Kubernetes. It builds upon GitOps principles and
integrates with existing technologies, like Argo CD, to streamline and automate
the progressive rollout of changes across the many stages of an application's
lifecycle.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p1 -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="\
   -X github.com/akuity/kargo/internal/version.version=%{version} \
   -X github.com/akuity/kargo/internal/version.buildDate=${BUILD_DATE} \
   -X github.com/akuity/kargo/internal/version.gitCommit=v%{version} \
   -X github.com/akuity/kargo/internal/version.gitTreeState=clean" \
   -o bin/%{executable_name} ./cmd/cli

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Tue Jan 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.2.2:
  * chore(backport release-1.2): docs: Added Advanced installation
    with Argo CD doc (#3381)
  * chore(backport release-1.2): docs: cli instructions doc (#3380)
  * chore(backport release-1.2): fix: fix faulty logic for handling
    possible double-encoding of github app private key (#3379)
  * chore(backport release-1.2): chore(cli): fix update command
    example (#3375)
  * chore(backport release-1.2): fix(ui): tolerate entra id RFC8414
    deviation (#3362)
  * chore(backport release-1.2): docs: add common chart
    configuration options (#3361)
  * chore(backport release-1.2): docs: fix incorrect callback url
    in oidc docs (#3360)
  * chore(backport release-1.2): docs: add/update roadmap (#3357)
  * chore(backport release-1.2): docs: add operator guide >
    security > oidc (#3354)
  * chore(backport release-1.2): docs: operator >  security >
    secure configuration (#3351)
* Thu Jan 23 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.2.1:
  * chore(backport release-1.2): refactor: change generic secret
    label (#3350)
  * chore(backport release-1.2): fix(cmd): improve Argo integration
    checks (#3349)
  * chore(backport release-1.2): docs: improve Argo CD integration
    document (#3344)
  * chore(backport release-1.2): docs: move promotion steps index
    to document (#3343)
  * chore(backport release-1.2): docs: make old and new docs live
    side by side (#3341)
  * chore(backport release-1.2): fix(directives): HTTP repo cache
    `helm-chart-update` (#3330)
  * chore(backport release-1.2): fix: Indent typo in 15-concepts.md
    (#3325)
  * chore(backport release-1.2): feat: versioned docs dropdown
    (#3280)
  * chore(backport release-1.2): docs: working with stages
    documentation (#3277)
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.2.0:
  * no CLI-related changes
* Fri Dec 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.1.2:
  * no CLI-related changes
* Tue Dec 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.1.1:
  * no CLI-related changes
* Sun Dec  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.1.0:
  * docs: fix cli download links in quickstart (#2794)
* Fri Dec  6 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.0.4:
  * no CLI-related changes
* Wed Oct 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.0.3:
  * no CLI-related changes
* Wed Oct 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.0.2:
  * no CLI-related changes
* Tue Oct 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.0.1:
  * chore(backport release-1.0): docs: fix cli download links in
    quickstart (#2798)
* Sat Oct 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.0.0:
  Major update, please see the release notes at
  https://github.com/akuity/kargo/releases/tag/v1.0.0
  CLI-related changes:
  * fix(cli): fix auth via --kubeconfig option (#2731)
  * fix(cli): fix flag in login command example (#2723)
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.9.1:
  * no CLI-related changes
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.9.0:
  Big update, please check the changelog
  https://github.com/akuity/kargo/releases/tag/v0.9.0
  CLI-related changes:
  * fix(kubeclient): retry patch on conflict (#2499)
  * fix(cli): retain config changes on re-login (#2388)
  * chore(kubeclient): tidy indexers and add tests (#2300)
* Fri Oct  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.8.8:
  * docs: update docs and scripts to lock release-0.8 branch into
    latest stable release (#2611)
  * chore(backport release-0.8): fix(kubeclient): retry patch on
    conflict (#2516)
  * chore(backport release-0.8): fix(docs): specify pnpm version
    for building docs (#2512)
  * chore(backport release-0.8): fix(ui): promote downstream subs
    in control flow stages was broken (#2498)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.8.7:
  * feat: support kustomize image newName override (#2471)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.8.6:
  * chore(backport release-0.8): fix(promotion): wait for open pull
    request (#2452)
* Sat Aug 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.8.5:
  * chore(backport release-0.8): fix(promotion): patch Application
    w/ Unstructured (#2443)
  * chore(backport release-0.8): fix(controller): improve logic to
    determine when syncing an argo cd app is required (#2442)
  * chore(backport release-0.8): fix: webhook server and controller
    permissions (#2436)
  * chore(backport release-0.8): feat(api): grant API to manage
    ConfigMap (#2434)
  * chore(backport release-0.8): fix(controller): account for
    differences in kargo, argo cd, and helm before searching for
    oci helm charts (#2412)
* Fri Aug  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.8.4:
  * chore(backport release-0.8): fix(promotion): sync ArgoCD
    Application without updates (#2408)
* Wed Aug  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.8.3:
  * chore(backport release-0.8): fix(promotion): always hard
    refresh ArgoCD App (#2398)
* Sat Aug  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.8.2:
  * chore(backport release-0.8): fix(ui): infinite redirect loop
    when renewing OIDC token (#2375)
  * chore(backport release-0.8): fix(controller): fix panic when
    last promotion has no freight collection (#2366)
* Fri Jul 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.8.1:
  * fix(ui): update colors hook (#2347)
  * chore(backport release-0.8): fix(ui): stop relying on
    deprecated field in images table (#2345)
  * chore(backport release-0.8): fix(ui): hide promotion button for
    control flow stages (#2343)
  * chore(backport release-0.8): fix(ui): properly display stage
    indicators in timeline after migration (#2337)
  * chore(backport release-0.8): fix(ui): incorrect DAG rendering
    for singular forward connection to node with multiple backward
    connections (#2335)
  * chore(backport release-0.8): docs: Update README.md (#2332)
  * chore(backport release-0.8): fix(ui): crash in stage details
    popover (#2331)
* Sat Jul 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.8.0:
  Big update with breaking changes (for Kargo itself, not the CLI)
  Please check the release notes:
  https://github.com/akuity/kargo/releases/tag/v0.8.0
  No apparent CLI-related changes
* Sat Jun 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.7.1:
  https://github.com/akuity/kargo/releases/tag/v0.7.1
  No apparent CLI-related changes
* Fri Jun  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.7.0:
  https://github.com/akuity/kargo/releases/tag/v0.7.0
  No apparent CLI-related changes
* Wed May  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.6.0:
  The Kargo team is thrilled to announce the release of v0.6.0,
  packed with stability improvements, enhancements, and new
  features. While the list of improvements and additions is
  extensive, we have highlighted some features you can look forward
  to exploring.
  If you are looking for a more complete list, please do consult
  the full changelog
  https://github.com/akuity/kargo/compare/v0.5.2...v0.6.0
  * Notes on Upgrading
    There is a single breaking change: the "well-known"
    kargo-secret-manager ClusterRole has been renamed to
    kargo-project-admin. However, this release includes a built-in
    upgrade reconciler to ensure a seamless upgrade process by
    automatically changing any project-level bindings referencing
    the old name to reference the new one.
    Please note that if you are upgrading from a version older than
    v0.5.0, you first need to upgrade to v0.5.x before upgrading to
    v0.6.0. This is due to breaking changes introduced in v0.5.0,
    for which no upgrade aid exists in this release.
  * Role Management
    Kargo will now create two roles in every Project: kargo-admin
    and kargo-viewer.
    The Kargo UI and CLI further allow creating and managing
    additional roles to provide scoped access to Kargo resources in
    a Project, which can be mapped to OIDC emails, subjects, and
    groups.
  * Warehouse Filters
    In v0.5.0, Warehouse subscription filters using regular
    expressions were introduced. Making it possible to, for
    instance, subscribe to a monorepo, but trigger the production
    of new Freight only when changes to relevant paths are
    detected.
    In this release, this feature has been further enhanced to
    support glob patterns (using a glob: prefix) and exact paths to
    files or directories. Additionally, the filters now apply to
    all commit selection strategies (and not just
    NewestFromBranch).
    For more detailed information, please take a look at the Kargo
    documentation.
  * Kubernetes Events
    Kargo will now emit Kubernetes Events for noteworthy changes.
    For example, when a new Promotion is created or the
    verification of Freight in a Stage succeeded. These events can
    also be viewed in the newly introduced events tab in the
    Project dashboard of the Kargo UI.
  * GitLab Merge Requests
    In v0.3.0, support for opening a GitHub pull request was added
    to Git-based promotion mechanisms. With the help of
    @PhilippParis, this has now been expanded to support GitLab
    merge requests.
  * UI Improvements
  - Project settings and AnalysisTemplate resources can now be
    managed through the UI.
  - Variety of bug fixes and other stability improvements.
  * Other Notable Features
  - Credentials can now include descriptions, which are displayed
    in the UI for informational purposes. We plan to expand this
    feature to more Kargo resource types in the future.
  - kargo get commands now support a --no-headers flag, which
    will avoid printing the column headers when provided.
  - kargo promote can now wait for a Promotion to finish using
  - -wait.
  - Kargo can now be configured (via the chart configuration) to
    sign commits with a GPG key.
  - Arbitrary volumes can be mounted to the optional Dex server
    (via the chart configuration) to support more complex
    connector configurations. This can for example be useful to
    configure Dex's google connector to get additional Google
    Groups information from your users, allowing you to assign
    permissions to members of a Google Group.
* Sat Apr 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.5.2:
  * fix: backport #1854 git url normalization logic to release-0.5
    (#1864)
  * fix: pass version info to UI during build -- release-0.5
    edition (#1803)
* Tue Apr  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.5.1:
  * chore: backport recent prs to release-0.5 (#1801)
  * fix(ui): backport protobuf fixes from `main` to `release-0.5`
    (#1800)
  * feat: backport analysistemplate and analysisrun views to
    release-0.5 (#1782)
* Fri Apr  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.5.0:
  Big update with breaking changes, see release notes at
  https://github.com/akuity/kargo/releases/tag/v0.5.0
  * All New CLI
    Breaking Change
  - The CLI has been virtually rewritten from the ground up. Up
    until now it wasn't an area of the project that had received
    the attention it deserved and we knew its UX needed quite a
    bit of work. All that has changed with this release!
  - The updated CLI should feel more intuitive across the board,
    behavior and help text should be more consistent from one
    command to the next, and we've added quite a bit of new
    functionality as well. Especially notable is that credentials
    can now be managed and verification processes re-run or even
    aborted via CLI.
  - If you upgrade Kargo's cluster-side components, you must also
    upgrade the CLI (if you use it).
* Sat Mar 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.4.5:
  * fix(cli): restore ability to read manifests from stdin -- 0.4
    edition (#1716)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.4.4:
  * chore(chart): be more careful about undefined values -- 0.4.x
    edition (#1603)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.4.3:
  * fix(chart): warnings in chart install/upgrade (#1558)
* Sat Feb 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.4.2:
  * fix(cli): don't involve kubeconfig in reading bytes from files
    (#1528)
* Sat Feb 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.4.1:
  * fix(crds): stage validation issue with kargo render promo mechs
    (#1519)
* Thu Feb 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kargo-cli: CLI for the Kargo Application lifecycle
  orchestration platform
